angular.module('app.controllers')

.controller('loginCtrl', ['$scope','$state', '$stateParams', '$http', '$rootScope', '$ionicPlatform', 'participantService', '$ionicPopup', // The following is the constructor function for this page's controller. See https://docs.angularjs.org/guide/controller
// You can include any angular dependencies as parameters for this function
// TIP: Access Route Parameters for your page via $stateParams.parameterName
function ($scope, $state, $stateParams, $http, $rootScope, $ionicPlatform, participantService, $ionicPopup){

    //check remembered credential when ready
    $ionicPlatform.ready(function(){
        
        username = window.localStorage.getItem("username");
        password = window.localStorage.getItem("password");        

        if(username !== null && password !== null){
            //$scope.doLogin(username, password, true);
            $scope.username = username;
            $scope.password = password;
            $scope.rememberMe = true;
        }
        else{
            $scope.username = '';
            $scope.password = '';
        }
        
    });

    $scope.register = function(){
        $state.go('registration', {}, {reload: true});
    }

    $scope.resetPassword = function(){
        $scope.enterEmail = {};
        var myPopup = $ionicPopup.show({
            template: '<input type="email" ng-model="enterEmail.email" style="border: 1px solid #cbcbcb;">',
            title: 'Reset Password',
            subTitle: 'Please enter your email address',
            scope: $scope,
            buttons: [
                { text: 'Cancel' },
                {
                    text: '<b>Reset</b>',
                    type: 'button-positive',
                    onTap: function(e) {
                        if (!$scope.enterEmail.email) {
                            //don't allow the user to close unless he enters email
                            e.preventDefault();
                        } else {
                            $scope.processResetPwd($scope.enterEmail.email);
                        }
                    }
                }
            ]
        });
    }

    $scope.processResetPwd = function(email){
        $rootScope.showLoader();
        participantService.recoverPassword(email).then(function(data){
            console.log(data);
            $rootScope.hideLoader();
            if(data.status === 1)
                alert('Reset password successfully, please check your email for new password!');
            else
                alert('Reset password failed, please try again or contact administrator!');
        });
    }

    $scope.doLogin = function(rememberMe){        
        
        $scope.username = $scope.username.trim();
        
        if($scope.username.length>0){            
            $rootScope.showLoader();
            
            var URL = $rootScope.API_SERVER + "?action=login";
            var requestData = {username: $scope.username, password: $scope.password};

            participantService.login(requestData).then(function(data){
                console.log(JSON.stringify(data));
                if(data.status === 1 && data.role === 'Participant'){
                    $scope.onLoginSuccess(data, rememberMe);
                }
                else if(data.status === 0 || data.role !== 'Participant'){
                    alert("Invalid login! Please try again.");                    
                }
                else{
                    alert("Connection error! Please try again."); 
                }

                $rootScope.hideLoader();
                
            })
            
        }
    }

    $scope.onLoginSuccess = function(data, rememberMe){
        $rootScope.loggedInUser = $scope.username.trim();
        $rootScope.loggedInUserId = data.user_id;
        $rootScope.QR = data.url_qrcode;
        $rootScope.loggedInUserData = {
            id: data.user_id,
            fullname: data.fullname,
            balance: data.balance,
            nric: data.nric
        };

        $rootScope.stallId = data.stallId;
        $rootScope.userRole = data.role;

        if(rememberMe){
            $scope.rememberCredential($scope.username, $scope.password);
        }
        else{
            $scope.clearCredential();
        }

        $state.go('bounceoff' + $rootScope.userRole);
    }     
   
  	$scope.rememberCredential = function(username, password){
        try{
            window.localStorage.setItem ("username",username);
            window.localStorage.setItem("password",password);
        }
  		catch(err){
            console.log(err);
        }
 	}

 	$scope.clearCredential = function(){
 		window.localStorage.removeItem("username");
        window.localStorage.removeItem("password");
 	}  
    
}])
