angular.module('app.controllers')

.controller('registrationCtrl', ['$scope', '$rootScope', '$state', '$stateParams', '$ionicPopup', 'participantService',  // The following is the constructor function for this page's controller. See https://docs.angularjs.org/guide/controller
// You can include any angular dependencies as parameters for this function
// TIP: Access Route Parameters for your page via $stateParams.parameterName
function ($scope, $rootScope, $state, $stateParams, $ionicPopup, participantService) {

    $scope.title = "Registration";

    $scope.init = function(){
        $scope.fullName = '';
        $scope.nric = '';        
        $scope.email = '';
        $scope.phoneNo = '';
        $scope.amount = '';
        $scope.stock = 0;
        $scope.displayAmount = '$0';
        
    }
    
    $scope.init();    

    $('#fullnameInput').keyup(function(e) { 
        
        var mEvent = e || window.event;
        var mPressed = mEvent.keyCode || mEvent.which;
        if (mPressed == 13) {
            document.getElementById('nricInput').focus();
        }
        
    });

    $('#nricInput').keyup(function(e) { 
        
        var mEvent = e || window.event;
        var mPressed = mEvent.keyCode || mEvent.which;
        if (mPressed == 13) {
            document.getElementById('emailInput').focus();
        }
        
    });

    $('#emailInput').keyup(function(e) { 
        
        var mEvent = e || window.event;
        var mPressed = mEvent.keyCode || mEvent.which;
        if (mPressed == 13) {
            document.getElementById('phoneInput').focus();
        }
        
    });

    //apply 2 decimal digit for amount input
    $('#amountInput').keyup(function(e) { 
        var mEvent = e || window.event;
        var mPressed = mEvent.keyCode || mEvent.which;        
        var amountString = this.value.toString();
        
        if(amountString !== ''){
            if(amountString.length<13){
                var amountSplit = amountString.split('.');
                if(amountSplit.length>1){
                    if(amountSplit[1].length> 2){
                        this.value = parseFloat(amountSplit[0] + '.' + amountSplit[1].substring(0,2));
                        
                    }
                }
            }
            else{
                this.value = parseFloat(amountString.substring(0,12));
            }
            $scope.amount = parseFloat(this.value);
            $scope.stock = $scope.amount;
            $scope.displayAmount = '$' + $scope.amount;
        }
        else{
            if(mPressed == 229){
                this.value = parseFloat($scope.stock);            
            }
            else{
                $scope.stock = 0;
                $scope.displayAmount = '$0';
            }
        }        
        $scope.$apply();       
        
    });

    $scope.doRegister = function(){
        //alert($scope.phoneNo);

        if($scope.amount == null || $scope.amount == ''){
            $scope.amount = 0;
        }   
       
        if($scope.fullName.trim() !== '' && $scope.nric.trim() !== '' && $scope.phoneNo != null && $scope.phoneNo != '' && $scope.amount >= 0 && $scope.amount <=999999999 && $scope.validateEmail($scope.email)){               

            $scope.registrationInfo = {
                full_name:     $scope.fullName.trim(),
                nric:           $scope.nric.trim(),
                email:          $scope.email.trim(),
                //area_code:      areaCode,
                phone_no:       $scope.phoneNo,
                //time_table:     timeSlot,
                topup:          $scope.amount
            };

            // $ionicPopup.show({

            //     templateUrl: 'templates/popup-registration-details.html',
            //     scope: $scope,
            //     cssClass: 'popup-vertical-buttons',
            //     buttons: [{
            //         text: 'Pay',
            //         type: 'button-positive',
            //         onTap: function(e){
            //             $scope.topupMethodListing();
            //         }
            //     },{
            //         text: 'Cancel',
            //         type: 'button-calm'
            //     },] 

            // });
            $scope.processRegister('Zero Amount');
        }
        else{

            if($scope.fullName === ''){
                alert("Participant name cannot be empty. Please try again!");
                setTimeout(function(){document.getElementById('fullnameInput').focus()},500);                    
            }                     
            else if($scope.nric === ''){
                alert("NRIC/Fin number cannot be empty. Please try again!");
                setTimeout(function(){document.getElementById('nricInput').focus()},500);
            }
            else if(!$scope.validateEmail($scope.email)){
                alert("Wrong email format, please try again!");
                setTimeout(function(){document.getElementById('emailInput').focus()},500);
            }
            else if($scope.phoneNo === null || $scope.phoneNo === ''){
                alert("Phone number cannot be empty. Please try again!");
                setTimeout(function(){document.getElementById('phoneInput').focus()},500);
            }
            else{
                alert("Top up value must be from $0 to $999 999 999. Please try again!");
                setTimeout(function(){document.getElementById('amountInput').focus()},500);     
            }

        }     
    }    

    $scope.processRegister = function(topupMethod){
        $rootScope.showLoader();
        participantService.insertNewParticipant($scope.registrationInfo).then(
            function(data){
                $rootScope.hideLoader();
                console.log(JSON.stringify(data));
                if(data.status === 1){
                    $scope.registeredId = data.participant_id;                        
                    $scope.generatedQRCode = data.url_qrcode;
                    $scope.transactionId = data.transaction_id;
                    $scope.topUpRegSuccess();
                }
                else if(data.status === -1){
                    alert("Duplicate participant detected, please check NRIC/ FIN number!");
                }
                else if(data.status === -2){
                    alert("Duplicate email detected, please try again!");
                }
                else if(data.status === 0){
                    alert("Failed to register new user!");
                }
                else{
                    console.log(data);
                    alert("Connection error, please try again!");
                }
            }
        );
    }

    $scope.topUpRegSuccess= function(){        
        $ionicPopup.show({
            title: 'Registration is successful',
            template: 'A comfirmation email and password has been sent to your email address. Please note that your username is your email address.',
            scope: $scope,          
            buttons: [
            {
                text: 'Continue',
                type: 'button-positive',
                onTap: function(e){
                    $state.go('login');
                }
            },]            
            
        })
    }


    $scope.validateEmail = function(email){
        if (/^\w+([\.-]?\w+)*@\w+([\.-]?\w+)*(\.\w{2,3})+$/.test(email)){
            return true;
        }
        else{
            return false;
        }
    }



}])