// Ionic Starter App

// angular.module is a global place for creating, registering and retrieving Angular modules
// 'starter' is the name of this angular module example (also set in a <body> attribute in index.html)
// the 2nd parameter is an array of 'requires'
// 'starter.services' is found in services.js
// 'starter.controllers' is found in controllers.js
angular.module('app', ['ionic', 'app.controllers', 'app.routes', 'app.directives','app.services',])

.config(['$provide', function($provide) {
    $provide.decorator("$exceptionHandler", ['$delegate', function($delegate) {
        return function(exception, cause) {
            $delegate(exception, cause);

            // Decorating standard exception handling behaviour by sending exception to crashlytics plugin
            var message = exception.toString();
            // Here, I rely on stacktrace-js (http://www.stacktracejs.com/) to format exception stacktraces before
            // sending it to the native bridge
            var stacktrace = $window.printStackTrace({e: exception});
            window.fabric.Crashlytics.addLog("ERROR: "+message+", stacktrace: "+stacktrace);
        };
    }]);
}])

.directive("nextFocus", function () {

    /** Usage:
      <input next-focus tabindex="0" id="field1">
      <input next-focus tabindex="1" id="field2">
      <input id="field3">
      Upon pressing ENTER key the directive will switch focus to
      the next field id e.g field2
      The last field should not have next-focus directive to avoid
      focusing on non-existing element.
      Works for Web, iOS (Go button) & Android (Next button) browsers, 
    **/
    return {
        restrict: 'A',
        link: function ($scope, selem, attrs) {
            selem.bind('keydown', function (e) {
                var code = e.keyCode || e.which;
                if (code === 13) {                    
                    var pageElems = document.querySelectorAll('input, select, textarea'),
                        elem = e.srcElement
                        focusNext = false,
                        len = pageElems.length;
                    for (var i = 0; i < len; i++) {
                        var pe = pageElems[i];
                        if (focusNext) {
                            e.preventDefault();
                            if (pe.style.display !== 'none') {
                                pe.focus();
                                break;
                            }
                        } else if (pe === e.srcElement) {
                            focusNext = true;
                        }
                    }
                }
            });
        }
    }

})

.run(function($ionicPlatform, $rootScope, $state, $ionicPopup, $http) {
  $ionicPlatform.ready(function() {
    // Hide the accessory bar by default (remove this to show the accessory bar above the keyboard
    // for form inputs)
    if (window.cordova && window.cordova.plugins && window.cordova.plugins.Keyboard) {
      cordova.plugins.Keyboard.hideKeyboardAccessoryBar(false);
      cordova.plugins.Keyboard.disableScroll(true);
    }
    if (window.StatusBar) {
      // org.apache.cordova.statusbar required
      StatusBar.styleDefault();
    }

    //
    // spinner loader using spinner plugin
    //
    $rootScope.showLoader = function(){
        var options = { dimBackground: true };
        SpinnerPlugin.activityStart("Loading...", options);
    }

    $rootScope.hideLoader = function(){
        SpinnerPlugin.activityStop();
    }
  });

  document.addEventListener('deviceready', function () {
    if(ionic.Platform.isIOS()){
  	  if (navigator.notification) { // Override default HTML alert with native dialog
  	      window.alert = function (message) {
  	          navigator.notification.alert(
  	              message,    // message
  	              null,       // callback
  	              "ALERT", // title
  	              'OK'        // buttonName
  	          );
  	      };
  	  }
    }
	}, false);

  $rootScope.formatNumber = function (n, width, z) {
      z = z || '0';
      n = n + '';
      return n.length >= width ? n : new Array(width - n.length + 1).join(z) + n;
  }

  //
  // server
  //
  //$rootScope.API_SERVER = "http://dzungnguyen.net/nep_prj/";
  //$rootScope.API_SERVER = "http://bounceoff.com.sg/bounceoff.com.sg/cash/";
  //$rootScope.API_SERVER = "http://bounceofffiesta.com.sg/staging_cash/";
  //$rootScope.API_SERVER = "http://54.169.222.114:8080/NEP/NEP/";
  $rootScope.API_SERVER = "http://209.58.164.23/NEP/NEP/";

  $rootScope.GETPromise =  function (URL) {
    console.log(URL);
    var returnData = {};
    return $http.get(URL, { withCredentials: true, timeout : 6000}).then(function(resp){
        returnData = resp.data;
        return returnData;
        
    }, function(err){
        returnData.staus = -500;
        returnData.err = err;                
        return returnData;
    })    
  }

  $rootScope.POSTPromise = function(URL, requestData){
    requestData = JSON.stringify(requestData);
    var returnData = {};
    return $http({
              method: 'POST',
              url: URL,
              data: requestData,
              headers: {'Content-Type': 'application/json'}
    })
    .then(function(resp){
              returnData = resp.data;
              return returnData;                      
          }, 
          function(err){                
              returnData.staus = -500;                
              return returnData;
          }
    )
  }

  $rootScope.goBack = function(){
      if ($state.current.name.indexOf("bounceoff") === 0) {
          $rootScope.closeApp();
      }else if($state.current.name === "login"){
          navigator.app.exitApp();          
      }
      else if($state.current.name === "registration"){
          $state.go('login');
      }
      else{
          $state.go('bounceoff' + $rootScope.userRole,{},{reload: true});
      }
  }

  $rootScope.closeApp = function (){
      $ionicPopup.show({
        title: 'Exit application?',                         
        buttons: [{
            text: 'Confirm',
            type: 'button-positive',
            onTap: function(e){
                navigator.app.exitApp();                      
            }
        },
        {
            text: 'Cancel',
            type: 'button-calm'
        },]
      });
  }

  $rootScope.showLoader = function(){
  }

  $rootScope.hideLoader = function(){
  }



  //
  // Android back button
  //

  $ionicPlatform.registerBackButtonAction(function(e) {
    //do your stuff
    e.preventDefault();
  }, 101);

  $ionicPlatform.onHardwareBackButton(function () {
      $rootScope.goBack();
  });

  // Ipad overlap viewport width css text
  var isIPad = ionic.Platform.isIPad();
  if(isIPad){
    $rootScope.customPadding = '2vw';
  }

})

 